@@ -94,8 +94,7 @@ checkLimit <- function(limit) {
 
 checkPriorObservation <- function(priorObservation) {
   checkmate::assertIntegerish(
-    priorObservation,
-    lower = 0, any.missing = F, len = 1, null.ok = T
+    priorObservation, lower = 0, any.missing = F, len = 1,
   )
 }
 
@@ -284,7 +283,7 @@ checkSameIndexMode <- function(sameIndexMode) {
 
 checkIngredientConceptId <- function(ingredientConceptId, cdm) {
   if (is.null(ingredientConceptId)) {
-    cli::cli_abort("ingredientConceptId ca not be NULL")
+    cli::cli_abort("ingredientConceptId can not be NULL")
   }
   if (!isInteger(ingredientConceptId)) {
     cli::cli_abort("ingredientConceptId is not an integer of length 1")
