@@ -57,13 +57,22 @@
 #' }
 #'
 summariseIndication <- function(cohort,
-                                cdm = attr(cohort, "cdm_reference"),
+                                cdm = lifecycle::deprecated(),
                                 strata = list(),
-                                minCellCount = 5) {
+                                minCellCount = lifecycle::deprecated()) {
+  if (lifecycle::is_present()) {
+    lifecycle::deprecate_soft(
+      when = "0.5.0", what = "summariseIndication(minCellCount = )"
+    )
+  }
+  if (lifecycle::is_present()) {
+    lifecycle::deprecate_soft(
+      when = "0.5.0", what = "summariseIndication(cdm = )"
+    )
+  }
+  cdm <- omopgenerics::cdmReference(cohort)
   # initialChecks
-  checkInputs(
-    cohort = cohort, cdm = cdm, strata = strata, minCellCount = minCellCount
-  )
+  checkInputs(cohort = cohort, cdm = cdm, strata = strata)
 
   indicationVariables <- indicationColumns(cohort)
 
@@ -72,15 +81,16 @@ summariseIndication <- function(cohort,
 
   # summarise indication columns
   result <- PatientProfiles::summariseResult(
-    table = cohort, group = list("cohort_name" = "cohort_name"),
+    table = cohort, group = list("cohort_name"),
+    includeOverallGroup = FALSE, includeOverallStrata = TRUE,
     strata = strata, variables = indicationVariables,
-    functions = c("count", "percentage"),
-    minCellCount = minCellCount
+    functions = c("count", "percentage")
   ) %>%
+    PatientProfiles::addCdmName(cdm = cdm) |>
     dplyr::mutate(
       variable_level = dplyr::if_else(
-        substr(.data$variable, 1, 15) == "indication_gap_",
-        lapply(strsplit(.data$variable, "_"), function(x) {
+        substr(.data$variable_name, 1, 15) == "indication_gap_",
+        lapply(strsplit(.data$variable_name, "_"), function(x) {
           if (length(x) > 3) {
             x <- paste0(x[-c(1:3)], collapse = "_")
             x <- paste0(toupper(substr(x, 1, 1)), substr(x, 2, nchar(x)))
@@ -92,18 +102,21 @@ summariseIndication <- function(cohort,
           unlist(),
         as.character(NA)
       ),
-      variable = dplyr::if_else(
-        substr(.data$variable, 1, 15) == "indication_gap_",
-        lapply(strsplit(.data$variable, "_"), function(x) {
+      variable_name = dplyr::if_else(
+        substr(.data$variable_name, 1, 15) == "indication_gap_",
+        lapply(strsplit(.data$variable_name, "_"), function(x) {
           x <- paste0(x[1:min(3, length(x))], collapse = "_")
           x <- indicationColumnName(x)
         }) %>%
           unlist(),
-        .data$variable
+        .data$variable_name
       ),
-      cdm_name = dplyr::coalesce(CDMConnector::cdmName(cdm), as.character(NA)),
-      result_type = "Summary indication"
-    )
+      result_type = "summarised_indication",
+      package_name = "DrugUtilisation",
+      package_version = as.character(utils::packageVersion("DrugUtilisation"))
+    ) |>
+    omopgenerics::newSummarisedResult() |>
+    omopgenerics::suppress(minCellCount = 5)
 
   return(result)
 }
